@@ -8,13 +8,14 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.1 $
-    \date   create:2002/12/31 update:$Date: 2003/01/01 12:06:18 $
+    \version $Revision: 1.2 $
+    \date   create:2002/12/31 update:$Date: 2003/02/22 13:29:51 $
 */
 #ifndef _MONA_SYSTEMINFO_
 #define _MONA_SYSTEMINFO_
 
 #include<monaTypes.h>
+#include<VirtualConsole.h>
 
 #define INTEL          0
 #define AMD            1
@@ -45,7 +46,7 @@ class SystemInfo {
   public:
     static SystemInfo& instance();
     bool hasCpuid() const;
-    void cpuid();
+    void printCpuid(VirtualConsole* console);
 };
 
 
