@@ -7,8 +7,8 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.6 $
-    \date   create:2002/11/11 update:$Date: 2003/01/07 15:22:14 $
+    \version $Revision: 1.8 $
+    \date   create:2002/11/11 update:$Date: 2003/03/01 05:22:03 $
 */
 
 #ifndef _MONA_TESTER_
@@ -17,9 +17,9 @@
 void hvectorTester();
 void operatorTester();
 void typeTester();
-void floppyTester();
 void processTester();
 void process1Tester();
 void process2Tester();
+void process3Tester();
 void STLTester();
 #endif
