@@ -9,11 +9,12 @@
     WITHOUT ANY WARRANTY
 
     \author  HigePon
-    \version $Revision: 1.4 $
-    \date   create:2002/08/04 update:$Date: 2002/12/24 13:08:14 $
+    \version $Revision: 1.7 $
+    \date   create:2002/08/04 update:$Date: 2003/03/11 16:01:18 $
 */
 
-#include<monaVga.h>
+#include <monaKernel.h>
+#include <global.h>
 
 extern "C" void __cxa_pure_virtual();
 extern "C" void _pure_virtual(void);
@@ -24,11 +25,11 @@ extern "C" int atexit( void (*func)(void));
     dummy
 
     \author HigePon
-    \date   create:2002/08/04 update:
+    \date   create:2002/08/04 update:2002/02/25
 */
 void __cxa_pure_virtual() {
 
-    _sysPrintln("__cxa_pure_virtual called");
+    g_console->printf("__cxa_pure_virtual called\n");
 }
 
 /*!
@@ -37,11 +38,11 @@ void __cxa_pure_virtual() {
     dummy
 
     \author HigePon
-    \date   create:2002/09/07 update:
+    \date   create:2002/09/07 update: 2003/02/25
 */
 void _pure_virtual() {
 
-    _sysPrintln("_pure_virtual called");
+    g_console->printf("_pure_virtual called\n");
 }
 
 /*!
@@ -50,6 +51,6 @@ void _pure_virtual() {
     dummy
 
     \author HigePon
-    \date   create:2002/08/08 update:2002/12/15
+    \date   create:2002/08/08 update:2002/02/25
 */
 int atexit( void (*func)(void)) {}
